##############################################################################
#
# Copyright (c) 2008 Kapil Thangavelu
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""
$Id: $
"""

from zope.viewlet.viewlet import CSSViewlet

YahooDataTable = CSSViewlet('yui/build/datatable/assets/datatable.css')
YahooDataTableSkin = CSSViewlet('yui/build/assets/skins/sam/datatable.css')
YahooTreeView = CSSViewlet('yui/build/assets/skins/sam/treeview.css')
YahooLogger = CSSViewlet('yui/build/logger/assets/skins/sam/logger.css')
YahooGridCSS = CSSViewlet('yui/build/reset-fonts-grids/reset-fonts-grids.css')




##############################################################################
#
# Copyright (c) 2008 Kapil Thangavelu
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
import os, unittest
from zope.testing import doctest

import zope.component
import zope.interface

from zope.app.publisher.browser.tests import test_directoryresource
DirectoryResourceFactory_orig = test_directoryresource.DirectoryResourceFactory

import ore.yui

class FauxYUIResource:

    def __init__(self, request):
        pass

    def __call__(self):
        return 'http://localhost/@@/yui'

class Test(test_directoryresource.Test):

    def setUp(self):
        test_directoryresource.Test.setUp(self)
        test_directoryresource.DirectoryResourceFactory = (
            zc.extjsresource.DirectoryResourceFactory)

    def tearDown(self):
        test_directoryresource.DirectoryResourceFactory = (
            DirectoryResourceFactory_orig)
        test_directoryresource.Test.tearDown(self)

    def test_set_blank_image_js(self):
        path = os.path.join(test_directoryresource.test_directory, 'testfiles')
        request = test_directoryresource.TestRequest()
        factory = zc.extjsresource.DirectoryResourceFactory(
            path, test_directoryresource.checker, 'testfiles')
        resource = factory(request)

        zope.component.provideAdapter(
            FauxExtjsResource,
            [test_directoryresource.TestRequest],
            zope.interface.Interface, 'extjs',
            )

        self.assertEqual(
            resource.publishTraverse(request, 'set_blank_image.js')(),
            "Ext.BLANK_IMAGE_URL = "
            "'http://localhost/@@/extjs/resources/images/default/s.gif';\n"
            )

def test_suite():
    return unittest.makeSuite(Test)



##############################################################################
#
# Copyright (c) 2008 Kapil Thangavelu
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
from zope.viewlet.viewlet import JavaScriptViewlet

YahooBase = JavaScriptViewlet('yui/yahoo/yahoo.js')
YahooEvent = JavaScriptViewlet('yui/event/event.js')
YahooConnection = JavaScriptViewlet('yui/connection/connection.js')
YahooDom = JavaScriptViewlet('yui/dom/dom.js')
YahooLogger = JavaScriptViewlet('yui/logger/logger-min.js')
YahooElement = JavaScriptViewlet('yui/element/element-beta.js')
YahooDataSource = JavaScriptViewlet('yui/datasource/datasource-beta.js')
YahooDataTable = JavaScriptViewlet('yui/datatable/datatable-beta.js')
YahooTree = JavaScriptViewlet('yui/treeview/treeview.js')



##############################################################################
#
# Copyright (c) 2008 Kapil Thangavelu
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
from zope import interface
from zope.publisher.interfaces.browser import IBrowserRequest
from zope.viewlet.interfaces import IViewletManager

class IYUILayer( IBrowserRequest ):
    """
    zope3 skin for yui
    """
    
class IYUIJavascript( IViewletManager ):
    """
    zope3 viewlet manager for yui js
    """
    
class IYUICSS( IViewletManager ):
    """
    zope3 css manager for yui
    """


##############################################################################
#
# Copyright (c) 2008 Kapil Thangavelu
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
import os, setuptools, shutil, urllib2, zipfile


rname = 'yui_2.5.1'
url_base = 'http://internap.dl.sourceforge.net/sourceforge/yui'
version = '0.4.2'
prefix = 'yui/'
include_parts = ['/assests', '/build']

dest = os.path.join(os.path.dirname(__file__),
                    'src', 'ore', 'yui', 'resources')
                    
                    
extpaths = []
if not os.path.exists(dest):
    zip_name = rname + '.zip'
    if not os.path.exists(zip_name):
        pkg_url = url_base+'/'+zip_name
        x = urllib2.urlopen( pkg_url ).read()
        open(zip_name, 'w').write(x)

    zfile = zipfile.ZipFile(zip_name, 'r')
    lprefix = len(prefix)-1

    for zname in sorted(zfile.namelist()):
        assert zname.startswith(prefix)
        zname_part = zname[lprefix:]
        include_p = False
        for pi in include_parts:
            if zname_part.startswith( pi ):
                include_p = True
        if not include_p: continue
        dname = dest + zname_part
        if dname[-1:] == '/':
            os.makedirs(dname)
        else:
            open(dname, 'w').write(zfile.read(zname))
            extpaths.append('yui/'+zname[lprefix:])
else:
    lbase = len(os.path.dirname(dest))+1
    for path, dirs, files in os.walk(dest):
        prefix = path[lbase:]
        for file in files:
            extpaths.append(os.path.join(prefix, file))

def read(*rnames):
    file_path = os.path.join(os.path.dirname(__file__), *rnames)
    return open( file_path ).read()

setuptools.setup(
    name = 'ore.yui',
    version = version,
    author='Kapil Thangavelu',
    author_email='kapil.foss@gmail.com',    
    description = "Zope3 Package of the YUI library",
    long_description=( read('src','ore','yui','README.txt')
                       + '\n\n' +
                       read('changes.txt')
                       ),
    url='http://pypi.python.org/pypi/ore.yui',
    packages = ['ore', 'ore.yui'],
    package_dir = {'':'src'},
    include_package_data = True,
    package_data = {'ore.yui': extpaths},
    namespace_packages = ['ore'],
    install_requires = [
        'setuptools',
        'zope.viewlet',
        'zc.resourcelibrary',
        ],
    zip_safe=False,
    classifiers=['Programming Language :: Python',
                 'Environment :: Web Environment',
                 'Topic :: Internet :: WWW/HTTP :: WSGI :: Application',
                 'Framework :: Zope3',
                 ],    
    )
